"""
Licensed to the Apache Software Foundation (ASF) under one
or more contributor license agreements.  See the NOTICE file
distributed with this work for additional information
regarding copyright ownership.  The ASF licenses this file
to you under the Apache License, Version 2.0 (the
"License"); you may not use this file except in compliance
with the License.  You may obtain a copy of the License at

  http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing,
software distributed under the License is distributed on an
"AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
KIND, either express or implied.  See the License for the
specific language governing permissions and limitations
under the License.
"""

# -*- coding: utf-8 -*-
from flask import current_app
from constants import AMC_CONFIG_PATH
try:
    import ConfigParser as cp
except ImportError:
    import configparser as cp

class ConfigManager(object):

    _instance = None

    def __new__(cls, *args, **kwargs):
        if not cls._instance:
            cls._instance = super(ConfigManager, cls).__new__(
                                cls, *args, **kwargs)
            cls._instance.__init__()
        return cls._instance

    def __init__(self):
        self.update_interval = -1
        self._initialise_update_interval()

    def get_update_interval(self):

        return self.update_interval

    def _initialise_update_interval(self):

        try:
            config = cp.RawConfigParser()
            if self.update_interval == -1:
                config.read(AMC_CONFIG_PATH)
                self.update_interval = config.getint('AMC', 'update_interval')
            return self.update_interval
        except Exception as e:
            return dict(update_interval="failure")

    def set_update_interval(self, update_interval):

        self.update_interval = int(update_interval)
        try:
            config = cp.RawConfigParser()
            #config.add_section('AMC')
            config.read(AMC_CONFIG_PATH)
            config.set('AMC', 'update_interval', update_interval)
            with open(AMC_CONFIG_PATH, 'wb') as configfile:
                config.write(configfile)
            return dict(status="success")
        except Exception:
            return dict(status="failure")


config_manager = ConfigManager()
